ssroute_data_eurostat library

Classes

Edge
An edge in the graph representing a directed connection between nodes.
Meta
Metadata describing the graph data schema and units.
Node
Model classes for Eurostat SeaRoute / MARNET graph data. A node in the graph representing a waypoint on the sea surface.

Properties

edgesData List
Gets the parsed edges data.
no setter
metaData Map<String, dynamic>
Gets the parsed meta data.
no setter
nodesData List
Gets the parsed nodes data.
no setter

Functions

loadEdges() List<Edge>
Loads the edges as a list of Edge objects from the package.
loadMeta() Meta
Loads the metadata Meta object (schema, units, etc.) from the package.
loadNodes() List<Node>
Loads the nodes as a list of Node objects from the package.