Node class

Model classes for Eurostat SeaRoute / MARNET graph data. A node in the graph representing a waypoint on the sea surface.

Constructors

Node({required int id, required double lon, required double lat})
const
Node.fromJson(List json)
Creates a Node from a JSON array id, lon, lat.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
final
lat double
final
lon double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List
Converts this Node to a JSON array id, lon, lat.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited