ssroute_data_eurostat
library
Classes
-
Edge
-
An edge in the graph representing a directed connection between nodes.
-
Meta
-
Metadata describing the graph data schema and units.
-
Node
-
Model classes for Eurostat SeaRoute / MARNET graph data.
A node in the graph representing a waypoint on the sea surface.