Node class
Model classes for Eurostat SeaRoute / MARNET graph data. A node in the graph representing a waypoint on the sea surface.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → List -
Converts this Node to a JSON array
id, lon, lat. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited